# valgrind finds invalid writes in libcmocka on arm and power
# see bug #1699304 for more information
%ifarch %{arm} ppc64le
%global run_valgrind_tests OFF
%else
%global run_valgrind_tests ON
%endif

# use arch-independent builddir (fixes docs build)
%global _vpath_builddir %{_vendor}-%{_target_os}-build

# library soname major version
%global somajor 2

Name:           libyang2
Version:        2.0.7
Release:        1%{?dist}
Summary:        YANG data modeling language library
License:        BSD
URL:            https://github.com/CESNET/libyang
Source:         %{url}/archive/v%{version}/libyang-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc
BuildRequires:  cmake(cmocka) >= 1.0.0
BuildRequires:  make
BuildRequires:  pkgconfig(libpcre2-8) >= 10.21
BuildRequires:  valgrind

%package tools
Summary:        YANG validator tools
Requires:       %{name}%{?_isa} = %{version}-%{release}
Provides:       libyang-tools = %{version}-%{release}
Obsoletes:      libyang-tools < 2

%package devel
Summary:        Development files for libyang2
Requires:       %{name}%{?_isa} = %{version}-%{release}
# conflict with legacy libyang-devel (v1)
Conflicts:      libyang-devel

%package devel-doc
Summary:        Documentation of libyang API
Requires:       %{name}-devel = %{version}-%{release}
BuildArch:      noarch
# conflict with legacy libyang-devel-doc (v1)
Conflicts:      libyang-devel-doc

%description
YANG data modeling language parser and toolkit
written (and providing API) in C.

%description tools
YANG validator tools.

%description devel
Headers of libyang library.

%description devel-doc
Documentation of libyang API.

%prep
%autosetup -p1 -n libyang-%{version}

%build
%cmake \
   -DCMAKE_BUILD_TYPE:String="RelWithDebInfo" \
   -DENABLE_VALGRIND_TESTS=%{run_valgrind_tests}

%cmake_build

# Build documentation
%cmake_build --target doc

%check
%ctest

%install
%cmake_install

mkdir -m0755 -p %{buildroot}/%{_docdir}/libyang
cp -a doc/html %{buildroot}/%{_docdir}/libyang/html

%files
%license LICENSE
%{_libdir}/libyang.so.%{somajor}{,.*}

%files tools
%{_bindir}/yanglint
%{_bindir}/yangre
%{_mandir}/man1/yanglint.1*

%files devel
%dir %{_includedir}/libyang/
%{_includedir}/libyang/*.h
%{_libdir}/libyang.so
%{_libdir}/pkgconfig/libyang.pc

%files devel-doc
%{_docdir}/libyang/


%changelog
* Thu Jul 15 2021 Jakub Ružička <jakub.ruzicka@nic.cz> - 2.0.7-1
- initial Fedora package
